@@ -540,7 +540,8 @@ def normalize_shortcuts(spec: str) -> Iterator[str]:
 
 
 def gen_go_code(defn: Definition) -> str:
-    lines = ['import "fmt"', 'import "strconv"', 'import "kitty/tools/config"', 'import "kitty/tools/utils/style"',
+    lines = ['import "fmt"', 'import "strconv"', 'import "github.com/kovidgoyal/kitty/tools/config"',
+             'import "github.com/kovidgoyal/kitty/tools/utils/style"',
              'var _ = fmt.Println', 'var _ = config.StringToBool', 'var _ = strconv.Atoi', 'var _ = style.ParseColor']
     a = lines.append
     keyboard_shortcuts = tuple(defn.iter_all_maps())
@@ -554,6 +555,11 @@ def gen_go_code(defn: Definition) -> str:
         if isinstance(option, MultiOption):
             go_types[name], go_parsers[name] = go_type_data(option.parser_func, option.ctype, True)
             multiopts.add(name)
+            defval = []
+            for x in option.items:
+                if x.add_to_default:
+                    defval.append(option.parser_func(x.defval_as_str))
+            defaults[name] = defval
         else:
             defaults[name] = option.parser_func(option.defval_as_string)
             if option.choices:
@@ -581,12 +587,8 @@ def gen_go_code(defn: Definition) -> str:
     a('func NewConfig() *Config {')
     a('return &Config{')
     from kitty.fast_data_types import Color
-    for name, pname in go_parsers.items():
-        if name in multiopts:
-            continue
-        d = defaults[name]
-        if not d:
-            continue
+
+    def basic_defval(d: Any) -> str:
         if isinstance(d, str):
             dval = f'{name}_{cval(d)}' if name in choices else f'`{d}`'
         elif isinstance(d, bool):
@@ -596,13 +598,23 @@ def gen_go_code(defn: Definition) -> str:
             for k, v in d.items():
                 dval += f'"{serialize_as_go_string(k)}": "{serialize_as_go_string(v)}",'
             dval += '}'
+        elif isinstance(d, list):
+            dval = '[]string{'
+            for k in d:
+                dval += f'"{serialize_as_go_string(k)}",'
+            dval += '}'
         elif isinstance(d, Color):
             dval = f'style.RGBA{{Red:{d.red}, Green: {d.green}, Blue: {d.blue}}}'
             if 'NullableColor' in go_types[name]:
                 dval = f'style.NullableColor{{IsSet: true, Color:{dval}}}'
         else:
             dval = repr(d)
-        a(f'{name}: {dval},')
+        return dval
+
+    for name, pname in go_parsers.items():
+        d = defaults[name]
+        if d:
+            a(f'{name}: {basic_defval(d)},')
     if keyboard_shortcuts:
         a('KeyboardShortcuts: []*config.KeyAction{')
         for sc in keyboard_shortcuts:
@@ -638,30 +650,36 @@ def gen_go_code(defn: Definition) -> str:
         a(f'default: return ans, fmt.Errorf("%#v is not a valid value for %s. Valid values are: %s", val, "{c}", "{vals}")')
         a('}''}')
 
+    has_parsers = bool(go_parsers or keyboard_shortcuts)
     a('func (c *Config) Parse(key, val string) (err error) {')
-    a('switch key {')
-    a('default: return fmt.Errorf("Unknown configuration key: %#v", key)')
-    for oname, pname in go_parsers.items():
-        ol = oname.lower()
-        is_multiple = oname in multiopts
-        a(f'case "{ol}":')
-        if is_multiple:
-            a(f'var temp_val []{go_types[oname]}')
-        else:
-            a(f'var temp_val {go_types[oname]}')
-        a(f'temp_val, err = {pname}')
-        a(f'if err != nil {{ return fmt.Errorf("Failed to parse {ol} = %#v with error: %w", val, err) }}')
-        if is_multiple:
-            a(f'c.{oname} = append(c.{oname}, temp_val...)')
-        else:
-            a(f'c.{oname} = temp_val')
-    if keyboard_shortcuts:
-        a('case "map":')
-        a('tempsc, err := config.ParseMap(val)')
-        a('if err != nil { return fmt.Errorf("Failed to parse map = %#v with error: %w", val, err) }')
-        a('c.KeyboardShortcuts = append(c.KeyboardShortcuts, tempsc)')
-    a('}')
-    a('return}')
+    if has_parsers:
+        if go_parsers:
+            a('switch key {')
+            a('default: return fmt.Errorf("Unknown configuration key: %#v", key)')
+            for oname, pname in go_parsers.items():
+                ol = oname.lower()
+                is_multiple = oname in multiopts
+                a(f'case "{ol}":')
+                if is_multiple:
+                    a(f'var temp_val []{go_types[oname]}')
+                else:
+                    a(f'var temp_val {go_types[oname]}')
+                a(f'temp_val, err = {pname}')
+                a(f'if err != nil {{ return fmt.Errorf("Failed to parse {ol} = %#v with error: %w", val, err) }}')
+                if is_multiple:
+                    a(f'c.{oname} = append(c.{oname}, temp_val...)')
+                else:
+                    a(f'c.{oname} = temp_val')
+        if keyboard_shortcuts:
+            a('case "map":')
+            a('tempsc, err := config.ParseMap(val)')
+            a('if err != nil { return fmt.Errorf("Failed to parse map = %#v with error: %w", val, err) }')
+            a('c.KeyboardShortcuts = append(c.KeyboardShortcuts, tempsc)')
+        a('}')
+        a('return}')
+    else:
+        a('return fmt.Errorf("Unknown configuration key: %#v", key)')
+        a('}')
     return '\n'.join(lines)
 
 
